/****************************************************************************
** Meta object code from reading C++ file 'pluginproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "pluginproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pluginproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SignonDaemonNS13PluginProcessE_t {};
} // unnamed namespace

template <> constexpr inline auto SignonDaemonNS::PluginProcess::qt_create_metaobjectdata<qt_meta_tag_ZN14SignonDaemonNS13PluginProcessE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignonDaemonNS::PluginProcess"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PluginProcess, qt_meta_tag_ZN14SignonDaemonNS13PluginProcessE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignonDaemonNS::PluginProcess::staticMetaObject = { {
    QMetaObject::SuperData::link<QProcess::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS13PluginProcessE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS13PluginProcessE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SignonDaemonNS13PluginProcessE_t>.metaTypes,
    nullptr
} };

void SignonDaemonNS::PluginProcess::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginProcess *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SignonDaemonNS::PluginProcess::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignonDaemonNS::PluginProcess::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS13PluginProcessE_t>.strings))
        return static_cast<void*>(this);
    return QProcess::qt_metacast(_clname);
}

int SignonDaemonNS::PluginProcess::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QProcess::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN14SignonDaemonNS11PluginProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto SignonDaemonNS::PluginProxy::qt_create_metaobjectdata<qt_meta_tag_ZN14SignonDaemonNS11PluginProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignonDaemonNS::PluginProxy",
        "processResultReply",
        "",
        "QVariantMap",
        "data",
        "processStore",
        "processUiRequest",
        "processRefreshRequest",
        "processError",
        "error",
        "message",
        "stateChanged",
        "state",
        "type",
        "mechanisms",
        "process",
        "inData",
        "mechanism",
        "processUi",
        "processRefresh",
        "cancel",
        "stop",
        "onReadStandardOutput",
        "onReadStandardError",
        "onExit",
        "exitCode",
        "QProcess::ExitStatus",
        "exitStatus",
        "onError",
        "QProcess::ProcessError",
        "err",
        "sessionDataReceived",
        "map",
        "blobIOError"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'processResultReply'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'processStore'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'processUiRequest'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'processRefreshRequest'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'processError'
        QtMocHelpers::SignalData<void(int, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 10 },
        }}),
        // Slot 'type'
        QtMocHelpers::SlotData<QString() const>(13, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'mechanisms'
        QtMocHelpers::SlotData<QStringList() const>(14, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'process'
        QtMocHelpers::SlotData<bool(const QVariantMap &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'processUi'
        QtMocHelpers::SlotData<bool(const QVariantMap &)>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 16 },
        }}),
        // Slot 'processRefresh'
        QtMocHelpers::SlotData<bool(const QVariantMap &)>(19, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 16 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onReadStandardOutput'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onReadStandardError'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onExit'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Slot 'onError'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'sessionDataReceived'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 32 },
        }}),
        // Slot 'blobIOError'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PluginProxy, qt_meta_tag_ZN14SignonDaemonNS11PluginProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignonDaemonNS::PluginProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS11PluginProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS11PluginProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SignonDaemonNS11PluginProxyE_t>.metaTypes,
    nullptr
} };

void SignonDaemonNS::PluginProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->processResultReply((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 1: _t->processStore((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 2: _t->processUiRequest((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 3: _t->processRefreshRequest((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 4: _t->processError((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: { QString _r = _t->type();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QStringList _r = _t->mechanisms();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->process((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->processUi((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->processRefresh((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->cancel(); break;
        case 12: _t->stop(); break;
        case 13: _t->onReadStandardOutput(); break;
        case 14: _t->onReadStandardError(); break;
        case 15: _t->onExit((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        case 16: _t->onError((*reinterpret_cast<std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        case 17: _t->sessionDataReceived((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 18: _t->blobIOError(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginProxy::*)(const QVariantMap & )>(_a, &PluginProxy::processResultReply, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginProxy::*)(const QVariantMap & )>(_a, &PluginProxy::processStore, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginProxy::*)(const QVariantMap & )>(_a, &PluginProxy::processUiRequest, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginProxy::*)(const QVariantMap & )>(_a, &PluginProxy::processRefreshRequest, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginProxy::*)(int , const QString & )>(_a, &PluginProxy::processError, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginProxy::*)(int , const QString & )>(_a, &PluginProxy::stateChanged, 5))
            return;
    }
}

const QMetaObject *SignonDaemonNS::PluginProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignonDaemonNS::PluginProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS11PluginProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SignonDaemonNS::PluginProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void SignonDaemonNS::PluginProxy::processResultReply(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SignonDaemonNS::PluginProxy::processStore(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SignonDaemonNS::PluginProxy::processUiRequest(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SignonDaemonNS::PluginProxy::processRefreshRequest(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SignonDaemonNS::PluginProxy::processError(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void SignonDaemonNS::PluginProxy::stateChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
