/****************************************************************************
** Meta object code from reading C++ file 'async-dbus-proxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "async-dbus-proxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'async-dbus-proxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6SignOn11PendingCallE_t {};
} // unnamed namespace

template <> constexpr inline auto SignOn::PendingCall::qt_create_metaobjectdata<qt_meta_tag_ZN6SignOn11PendingCallE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignOn::PendingCall",
        "finished",
        "",
        "QDBusPendingCallWatcher*",
        "watcher",
        "success",
        "error",
        "QDBusError",
        "requeueRequested",
        "onFinished",
        "onInterfaceDestroyed",
        "fail"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'finished'
        QtMocHelpers::SignalData<void(QDBusPendingCallWatcher *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'success'
        QtMocHelpers::SignalData<void(QDBusPendingCallWatcher *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const QDBusError &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 6 },
        }}),
        // Signal 'requeueRequested'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onInterfaceDestroyed'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fail'
        QtMocHelpers::SlotData<void(const QDBusError &)>(11, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PendingCall, qt_meta_tag_ZN6SignOn11PendingCallE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignOn::PendingCall::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn11PendingCallE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn11PendingCallE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SignOn11PendingCallE_t>.metaTypes,
    nullptr
} };

void SignOn::PendingCall::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PendingCall *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->finished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 1: _t->success((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 2: _t->error((*reinterpret_cast<std::add_pointer_t<QDBusError>>(_a[1]))); break;
        case 3: _t->requeueRequested(); break;
        case 4: _t->onFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 5: _t->onInterfaceDestroyed(); break;
        case 6: _t->fail((*reinterpret_cast<std::add_pointer_t<QDBusError>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusError >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusError >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PendingCall::*)(QDBusPendingCallWatcher * )>(_a, &PendingCall::finished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PendingCall::*)(QDBusPendingCallWatcher * )>(_a, &PendingCall::success, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PendingCall::*)(const QDBusError & )>(_a, &PendingCall::error, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PendingCall::*)()>(_a, &PendingCall::requeueRequested, 3))
            return;
    }
}

const QMetaObject *SignOn::PendingCall::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignOn::PendingCall::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn11PendingCallE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SignOn::PendingCall::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void SignOn::PendingCall::finished(QDBusPendingCallWatcher * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SignOn::PendingCall::success(QDBusPendingCallWatcher * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SignOn::PendingCall::error(const QDBusError & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SignOn::PendingCall::requeueRequested()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN6SignOn14AsyncDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto SignOn::AsyncDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN6SignOn14AsyncDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignOn::AsyncDBusProxy",
        "connectionNeeded",
        "",
        "objectPathNeeded",
        "setConnection",
        "QDBusConnection",
        "connection",
        "setDisconnected",
        "onCallFinished",
        "QDBusPendingCallWatcher*",
        "watcher",
        "onRequeueRequested"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'connectionNeeded'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'objectPathNeeded'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setConnection'
        QtMocHelpers::SlotData<void(const QDBusConnection &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'setDisconnected'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCallFinished'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'onRequeueRequested'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AsyncDBusProxy, qt_meta_tag_ZN6SignOn14AsyncDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignOn::AsyncDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn14AsyncDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn14AsyncDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SignOn14AsyncDBusProxyE_t>.metaTypes,
    nullptr
} };

void SignOn::AsyncDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AsyncDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->connectionNeeded(); break;
        case 1: _t->objectPathNeeded(); break;
        case 2: _t->setConnection((*reinterpret_cast<std::add_pointer_t<QDBusConnection>>(_a[1]))); break;
        case 3: _t->setDisconnected(); break;
        case 4: _t->onCallFinished((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 5: _t->onRequeueRequested(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AsyncDBusProxy::*)()>(_a, &AsyncDBusProxy::connectionNeeded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AsyncDBusProxy::*)()>(_a, &AsyncDBusProxy::objectPathNeeded, 1))
            return;
    }
}

const QMetaObject *SignOn::AsyncDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignOn::AsyncDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn14AsyncDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SignOn::AsyncDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void SignOn::AsyncDBusProxy::connectionNeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SignOn::AsyncDBusProxy::objectPathNeeded()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN6SignOn21SignondAsyncDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto SignOn::SignondAsyncDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN6SignOn21SignondAsyncDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignOn::SignondAsyncDBusProxy"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SignondAsyncDBusProxy, qt_meta_tag_ZN6SignOn21SignondAsyncDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignOn::SignondAsyncDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<AsyncDBusProxy::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn21SignondAsyncDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn21SignondAsyncDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SignOn21SignondAsyncDBusProxyE_t>.metaTypes,
    nullptr
} };

void SignOn::SignondAsyncDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignondAsyncDBusProxy *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *SignOn::SignondAsyncDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignOn::SignondAsyncDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn21SignondAsyncDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    return AsyncDBusProxy::qt_metacast(_clname);
}

int SignOn::SignondAsyncDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AsyncDBusProxy::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
