/****************************************************************************
** Meta object code from reading C++ file 'signonidentity.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "signonidentity.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'signonidentity.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SignonDaemonNS14SignonIdentityE_t {};
} // unnamed namespace

template <> constexpr inline auto SignonDaemonNS::SignonIdentity::qt_create_metaobjectdata<qt_meta_tag_ZN14SignonDaemonNS14SignonIdentityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignonDaemonNS::SignonIdentity",
        "unregistered",
        "",
        "infoUpdated",
        "stored",
        "SignonIdentity*",
        "identity",
        "requestCredentialsUpdate",
        "message",
        "CredentialsUpdateCb",
        "callback",
        "getInfo",
        "Error",
        "SignonIdentityInfo*",
        "info",
        "addReference",
        "reference",
        "appId",
        "removeReference",
        "verifyUser",
        "QVariantMap",
        "params",
        "VerifyUserCb",
        "verifySecret",
        "secret",
        "bool*",
        "verified",
        "remove",
        "RemoveCb",
        "signOut",
        "SignOutCb",
        "store",
        "quint32*",
        "id",
        "queryUiSlot",
        "QDBusPendingCallWatcher*",
        "call",
        "verifyUiSlot",
        "removeCompleted",
        "signOutCompleted",
        "onCredentialsUpdated"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'unregistered'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'infoUpdated'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'stored'
        QtMocHelpers::SignalData<void(SignonIdentity *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'requestCredentialsUpdate'
        QtMocHelpers::SlotData<void(const QString &, const CredentialsUpdateCb &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'getInfo'
        QtMocHelpers::SlotData<Error(SignonIdentityInfo *)>(11, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'addReference'
        QtMocHelpers::SlotData<Error(const QString &, const QString &)>(15, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'removeReference'
        QtMocHelpers::SlotData<Error(const QString &, const QString &)>(18, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'verifyUser'
        QtMocHelpers::SlotData<void(const QVariantMap &, const VerifyUserCb &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { 0x80000000 | 22, 10 },
        }}),
        // Slot 'verifySecret'
        QtMocHelpers::SlotData<Error(const QString &, bool *)>(23, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void(const RemoveCb &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 10 },
        }}),
        // Slot 'signOut'
        QtMocHelpers::SlotData<void(const SignOutCb &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 10 },
        }}),
        // Slot 'store'
        QtMocHelpers::SlotData<Error(const QVariantMap &, const QString &, quint32 *)>(31, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 20, 14 }, { QMetaType::QString, 17 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'queryUiSlot'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *, const CredentialsUpdateCb &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'verifyUiSlot'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *, const VerifyUserCb &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { 0x80000000 | 22, 10 },
        }}),
        // Slot 'removeCompleted'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *, const RemoveCb &)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { 0x80000000 | 28, 10 },
        }}),
        // Slot 'signOutCompleted'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *, const SignOutCb &)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { 0x80000000 | 30, 10 },
        }}),
        // Slot 'onCredentialsUpdated'
        QtMocHelpers::SlotData<void(quint32)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::UInt, 33 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SignonIdentity, qt_meta_tag_ZN14SignonDaemonNS14SignonIdentityE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignonDaemonNS::SignonIdentity::staticMetaObject = { {
    QMetaObject::SuperData::link<SignonDisposable::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS14SignonIdentityE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS14SignonIdentityE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SignonDaemonNS14SignonIdentityE_t>.metaTypes,
    nullptr
} };

void SignonDaemonNS::SignonIdentity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignonIdentity *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->unregistered(); break;
        case 1: _t->infoUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->stored((*reinterpret_cast<std::add_pointer_t<SignonIdentity*>>(_a[1]))); break;
        case 3: _t->requestCredentialsUpdate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<CredentialsUpdateCb>>(_a[2]))); break;
        case 4: { Error _r = _t->getInfo((*reinterpret_cast<std::add_pointer_t<SignonIdentityInfo*>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Error*>(_a[0]) = std::move(_r); }  break;
        case 5: { Error _r = _t->addReference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Error*>(_a[0]) = std::move(_r); }  break;
        case 6: { Error _r = _t->removeReference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Error*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->verifyUser((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<VerifyUserCb>>(_a[2]))); break;
        case 8: { Error _r = _t->verifySecret((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Error*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->remove((*reinterpret_cast<std::add_pointer_t<RemoveCb>>(_a[1]))); break;
        case 10: _t->signOut((*reinterpret_cast<std::add_pointer_t<SignOutCb>>(_a[1]))); break;
        case 11: { Error _r = _t->store((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<quint32*>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Error*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->queryUiSlot((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<CredentialsUpdateCb>>(_a[2]))); break;
        case 13: _t->verifyUiSlot((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<VerifyUserCb>>(_a[2]))); break;
        case 14: _t->removeCompleted((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<RemoveCb>>(_a[2]))); break;
        case 15: _t->signOutCompleted((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<SignOutCb>>(_a[2]))); break;
        case 16: _t->onCredentialsUpdated((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignonIdentity* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SignonIdentity::*)()>(_a, &SignonIdentity::unregistered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignonIdentity::*)(int )>(_a, &SignonIdentity::infoUpdated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignonIdentity::*)(SignonIdentity * )>(_a, &SignonIdentity::stored, 2))
            return;
    }
}

const QMetaObject *SignonDaemonNS::SignonIdentity::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignonDaemonNS::SignonIdentity::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS14SignonIdentityE_t>.strings))
        return static_cast<void*>(this);
    return SignonDisposable::qt_metacast(_clname);
}

int SignonDaemonNS::SignonIdentity::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SignonDisposable::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void SignonDaemonNS::SignonIdentity::unregistered()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SignonDaemonNS::SignonIdentity::infoUpdated(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SignonDaemonNS::SignonIdentity::stored(SignonIdentity * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
