/****************************************************************************
** Meta object code from reading C++ file 'signonsessioncore.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "signonsessioncore.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'signonsessioncore.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SignonDaemonNS17SignonSessionCoreE_t {};
} // unnamed namespace

template <> constexpr inline auto SignonDaemonNS::SignonSessionCore::qt_create_metaobjectdata<qt_meta_tag_ZN14SignonDaemonNS17SignonSessionCoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignonDaemonNS::SignonSessionCore",
        "stateChanged",
        "",
        "requestId",
        "state",
        "message",
        "queryAvailableMechanisms",
        "wantedMechanisms",
        "process",
        "PeerContext",
        "peerContext",
        "QVariantMap",
        "sessionDataVa",
        "mechanism",
        "cancelKey",
        "ProcessCb",
        "callback",
        "cancel",
        "setId",
        "id",
        "credentialsSystemReady",
        "startNewRequest",
        "processResultReply",
        "data",
        "processStore",
        "processUiRequest",
        "processRefreshRequest",
        "processError",
        "err",
        "stateChangedSlot",
        "queryUiSlot",
        "QDBusPendingCallWatcher*",
        "call"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(const QString &, int, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'queryAvailableMechanisms'
        QtMocHelpers::SlotData<QStringList(const QStringList &)>(6, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Slot 'process'
        QtMocHelpers::SlotData<void(const PeerContext &, const QVariantMap &, const QString &, const QString &, const ProcessCb &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 }, { QMetaType::QString, 13 }, { QMetaType::QString, 14 },
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'setId'
        QtMocHelpers::SlotData<void(quint32)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 19 },
        }}),
        // Slot 'credentialsSystemReady'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'startNewRequest'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'processResultReply'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 23 },
        }}),
        // Slot 'processStore'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 23 },
        }}),
        // Slot 'processUiRequest'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 23 },
        }}),
        // Slot 'processRefreshRequest'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 23 },
        }}),
        // Slot 'processError'
        QtMocHelpers::SlotData<void(int, const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 28 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'stateChangedSlot'
        QtMocHelpers::SlotData<void(int, const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'queryUiSlot'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 31, 32 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SignonSessionCore, qt_meta_tag_ZN14SignonDaemonNS17SignonSessionCoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignonDaemonNS::SignonSessionCore::staticMetaObject = { {
    QMetaObject::SuperData::link<SignonDisposable::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS17SignonSessionCoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS17SignonSessionCoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SignonDaemonNS17SignonSessionCoreE_t>.metaTypes,
    nullptr
} };

void SignonDaemonNS::SignonSessionCore::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignonSessionCore *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 1: { QStringList _r = _t->queryAvailableMechanisms((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->process((*reinterpret_cast<std::add_pointer_t<PeerContext>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<ProcessCb>>(_a[5]))); break;
        case 3: _t->cancel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->setId((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 5: _t->credentialsSystemReady(); break;
        case 6: _t->startNewRequest(); break;
        case 7: _t->processResultReply((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 8: _t->processStore((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 9: _t->processUiRequest((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 10: _t->processRefreshRequest((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 11: _t->processError((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 12: _t->stateChangedSlot((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->queryUiSlot((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SignonSessionCore::*)(const QString & , int , const QString & )>(_a, &SignonSessionCore::stateChanged, 0))
            return;
    }
}

const QMetaObject *SignonDaemonNS::SignonSessionCore::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignonDaemonNS::SignonSessionCore::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS17SignonSessionCoreE_t>.strings))
        return static_cast<void*>(this);
    return SignonDisposable::qt_metacast(_clname);
}

int SignonDaemonNS::SignonSessionCore::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = SignonDisposable::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void SignonDaemonNS::SignonSessionCore::stateChanged(const QString & _t1, int _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
