/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was com.nokia.SingleSignOn.Backup.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "backup_adaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class BackupclientAdaptor
 */

BackupclientAdaptor::BackupclientAdaptor(QObject *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

BackupclientAdaptor::~BackupclientAdaptor()
{
    // destructor
}

uchar BackupclientAdaptor::backupFinished()
{
    // handle method call com.nokia.backupclient.backupFinished
    uchar out0{};
    QMetaObject::invokeMethod(parent(), "backupFinished", Q_RETURN_ARG(uchar, out0));
    return out0;
}

uchar BackupclientAdaptor::backupStarts()
{
    // handle method call com.nokia.backupclient.backupStarts
    uchar out0{};
    QMetaObject::invokeMethod(parent(), "backupStarts", Q_RETURN_ARG(uchar, out0));
    return out0;
}

uchar BackupclientAdaptor::restoreFinished()
{
    // handle method call com.nokia.backupclient.restoreFinished
    uchar out0{};
    QMetaObject::invokeMethod(parent(), "restoreFinished", Q_RETURN_ARG(uchar, out0));
    return out0;
}

uchar BackupclientAdaptor::restoreStarts()
{
    // handle method call com.nokia.backupclient.restoreStarts
    uchar out0{};
    QMetaObject::invokeMethod(parent(), "restoreStarts", Q_RETURN_ARG(uchar, out0));
    return out0;
}

