/****************************************************************************
** Meta object code from reading C++ file 'signonauthsessionadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "signonauthsessionadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'signonauthsessionadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SignonDaemonNS24SignonAuthSessionAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SignonDaemonNS::SignonAuthSessionAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN14SignonDaemonNS24SignonAuthSessionAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignonDaemonNS::SignonAuthSessionAdaptor",
        "D-Bus Interface",
        "com.google.code.AccountsSSO.SingleSignOn.AuthSession",
        "stateChanged",
        "",
        "state",
        "message",
        "unregistered",
        "queryAvailableMechanisms",
        "wantedMechanisms",
        "process",
        "QVariantMap",
        "sessionDataVa",
        "mechanism",
        "cancel",
        "Q_NOREPLY",
        "setId",
        "id",
        "objectUnref"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void(int, const QString &)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::QString, 6 },
        }}),
        // Signal 'unregistered'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'queryAvailableMechanisms'
        QtMocHelpers::SlotData<QStringList(const QStringList &)>(8, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QStringList, 9 },
        }}),
        // Slot 'process'
        QtMocHelpers::SlotData<QVariantMap(const QVariantMap &, const QString &)>(10, 4, QMC::AccessPublic, 0x80000000 | 11, {{
            { 0x80000000 | 11, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(14, 15, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setId'
        QtMocHelpers::SlotData<void(quint32)>(16, 15, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 17 },
        }}),
        // Slot 'objectUnref'
        QtMocHelpers::SlotData<void()>(18, 15, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SignonAuthSessionAdaptor, qt_meta_tag_ZN14SignonDaemonNS24SignonAuthSessionAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SignonDaemonNS::SignonAuthSessionAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS24SignonAuthSessionAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS24SignonAuthSessionAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SignonDaemonNS24SignonAuthSessionAdaptorE_t>.metaTypes,
    nullptr
} };

void SignonDaemonNS::SignonAuthSessionAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignonAuthSessionAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->stateChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->unregistered(); break;
        case 2: { QStringList _r = _t->queryAvailableMechanisms((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 3: { QVariantMap _r = _t->process((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->cancel(); break;
        case 5: _t->setId((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 6: _t->objectUnref(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SignonAuthSessionAdaptor::*)(int , const QString & )>(_a, &SignonAuthSessionAdaptor::stateChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SignonAuthSessionAdaptor::*)()>(_a, &SignonAuthSessionAdaptor::unregistered, 1))
            return;
    }
}

const QMetaObject *SignonDaemonNS::SignonAuthSessionAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignonDaemonNS::SignonAuthSessionAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS24SignonAuthSessionAdaptorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int SignonDaemonNS::SignonAuthSessionAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void SignonDaemonNS::SignonAuthSessionAdaptor::stateChanged(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void SignonDaemonNS::SignonAuthSessionAdaptor::unregistered()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
