/****************************************************************************
** Meta object code from reading C++ file 'identityimpl.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "identityimpl.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identityimpl.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6SignOn12IdentityImplE_t {};
} // unnamed namespace

template <> constexpr inline auto SignOn::IdentityImpl::qt_create_metaobjectdata<qt_meta_tag_ZN6SignOn12IdentityImplE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignOn::IdentityImpl",
        "errorReply",
        "",
        "QDBusError",
        "err",
        "storeCredentialsReply",
        "QDBusPendingCallWatcher*",
        "call",
        "removeReply",
        "addReferenceReply",
        "removeReferenceReply",
        "getInfoReply",
        "verifyUserReply",
        "verifySecretReply",
        "signOutReply",
        "infoUpdated",
        "remoteObjectDestroyed",
        "sendRegisterRequest",
        "queryAvailableMethods",
        "requestCredentialsUpdate",
        "message",
        "storeCredentials",
        "IdentityInfo",
        "info",
        "remove",
        "addReference",
        "reference",
        "removeReference",
        "queryInfo",
        "verifyUser",
        "QVariantMap",
        "params",
        "verifySecret",
        "secret",
        "signOut",
        "authSessionCancelReply",
        "SignOn::Error",
        "registerReply",
        "deleteServiceProxy"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'errorReply'
        QtMocHelpers::SlotData<void(const QDBusError &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'storeCredentialsReply'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'removeReply'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addReferenceReply'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeReferenceReply'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getInfoReply'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'verifyUserReply'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'verifySecretReply'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'signOutReply'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'infoUpdated'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'remoteObjectDestroyed'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'sendRegisterRequest'
        QtMocHelpers::SlotData<bool()>(17, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'queryAvailableMethods'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'requestCredentialsUpdate'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'requestCredentialsUpdate'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'storeCredentials'
        QtMocHelpers::SlotData<void(const IdentityInfo &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'remove'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'addReference'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'addReference'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'removeReference'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'removeReference'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'queryInfo'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'verifyUser'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'verifyUser'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'verifyUser'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'verifySecret'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'signOut'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'authSessionCancelReply'
        QtMocHelpers::SlotData<void(const SignOn::Error &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 36, 4 },
        }}),
        // Slot 'registerReply'
        QtMocHelpers::SlotData<void(QDBusPendingCallWatcher *)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'deleteServiceProxy'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IdentityImpl, qt_meta_tag_ZN6SignOn12IdentityImplE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignOn::IdentityImpl::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn12IdentityImplE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn12IdentityImplE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SignOn12IdentityImplE_t>.metaTypes,
    nullptr
} };

void SignOn::IdentityImpl::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IdentityImpl *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->errorReply((*reinterpret_cast<std::add_pointer_t<QDBusError>>(_a[1]))); break;
        case 1: _t->storeCredentialsReply((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 2: _t->removeReply(); break;
        case 3: _t->addReferenceReply(); break;
        case 4: _t->removeReferenceReply(); break;
        case 5: _t->getInfoReply((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 6: _t->verifyUserReply((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 7: _t->verifySecretReply((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 8: _t->signOutReply(); break;
        case 9: _t->infoUpdated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->remoteObjectDestroyed(); break;
        case 11: { bool _r = _t->sendRegisterRequest();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->queryAvailableMethods(); break;
        case 13: _t->requestCredentialsUpdate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->requestCredentialsUpdate(); break;
        case 15: _t->storeCredentials((*reinterpret_cast<std::add_pointer_t<IdentityInfo>>(_a[1]))); break;
        case 16: _t->remove(); break;
        case 17: _t->addReference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->addReference(); break;
        case 19: _t->removeReference((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 20: _t->removeReference(); break;
        case 21: _t->queryInfo(); break;
        case 22: _t->verifyUser((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->verifyUser(); break;
        case 24: _t->verifyUser((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 25: _t->verifySecret((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->signOut(); break;
        case 27: _t->authSessionCancelReply((*reinterpret_cast<std::add_pointer_t<SignOn::Error>>(_a[1]))); break;
        case 28: _t->registerReply((*reinterpret_cast<std::add_pointer_t<QDBusPendingCallWatcher*>>(_a[1]))); break;
        case 29: _t->deleteServiceProxy(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusError >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::Error >(); break;
            }
            break;
        case 28:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusPendingCallWatcher* >(); break;
            }
            break;
        }
    }
}

const QMetaObject *SignOn::IdentityImpl::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignOn::IdentityImpl::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn12IdentityImplE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SignOn::IdentityImpl::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    return _id;
}
QT_WARNING_POP
