/****************************************************************************
** Meta object code from reading C++ file 'signondaemonadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "signondaemonadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'signondaemonadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14SignonDaemonNS19SignonDaemonAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto SignonDaemonNS::SignonDaemonAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN14SignonDaemonNS19SignonDaemonAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignonDaemonNS::SignonDaemonAdaptor",
        "D-Bus Interface",
        "com.google.code.AccountsSSO.SingleSignOn.AuthService",
        "registerNewIdentity",
        "QDBusObjectPath",
        "",
        "applicationContext",
        "getIdentity",
        "id",
        "QDBusObjectPath&",
        "objectPath",
        "QVariantMap&",
        "identityData",
        "getAuthSessionObjectPath",
        "type",
        "queryMethods",
        "queryMechanisms",
        "method",
        "queryIdentities",
        "QVariantMap",
        "filter",
        "clear",
        "onIdentityAccessReplyFinished",
        "onAuthSessionAccessReplyFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'registerNewIdentity'
        QtMocHelpers::SlotData<QDBusObjectPath(const QString &)>(3, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'getIdentity'
        QtMocHelpers::SlotData<void(const quint32, const QString &, QDBusObjectPath &, QVariantMap &)>(7, 5, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 8 }, { QMetaType::QString, 6 }, { 0x80000000 | 9, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'getAuthSessionObjectPath'
        QtMocHelpers::SlotData<QDBusObjectPath(const quint32, const QString &, const QString &)>(13, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { QMetaType::UInt, 8 }, { QMetaType::QString, 6 }, { QMetaType::QString, 14 },
        }}),
        // Slot 'queryMethods'
        QtMocHelpers::SlotData<QStringList()>(15, 5, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'queryMechanisms'
        QtMocHelpers::SlotData<QStringList(const QString &)>(16, 5, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'queryIdentities'
        QtMocHelpers::SlotData<void(const QVariantMap &, const QString &)>(18, 5, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::QString, 6 },
        }}),
        // Slot 'clear'
        QtMocHelpers::SlotData<bool()>(21, 5, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'onIdentityAccessReplyFinished'
        QtMocHelpers::SlotData<void()>(22, 5, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onAuthSessionAccessReplyFinished'
        QtMocHelpers::SlotData<void()>(23, 5, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SignonDaemonAdaptor, qt_meta_tag_ZN14SignonDaemonNS19SignonDaemonAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject SignonDaemonNS::SignonDaemonAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS19SignonDaemonAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS19SignonDaemonAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14SignonDaemonNS19SignonDaemonAdaptorE_t>.metaTypes,
    nullptr
} };

void SignonDaemonNS::SignonDaemonAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SignonDaemonAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusObjectPath _r = _t->registerNewIdentity((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->getIdentity((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[4]))); break;
        case 2: { QDBusObjectPath _r = _t->getAuthSessionObjectPath((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 3: { QStringList _r = _t->queryMethods();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 4: { QStringList _r = _t->queryMechanisms((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->queryIdentities((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: { bool _r = _t->clear();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->onIdentityAccessReplyFinished(); break;
        case 8: _t->onAuthSessionAccessReplyFinished(); break;
        default: ;
        }
    }
}

const QMetaObject *SignonDaemonNS::SignonDaemonAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignonDaemonNS::SignonDaemonAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14SignonDaemonNS19SignonDaemonAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int SignonDaemonNS::SignonDaemonAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
