/****************************************************************************
** Meta object code from reading C++ file 'identity.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "identity.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identity.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6SignOn8IdentityE_t {};
} // unnamed namespace

template <> constexpr inline auto SignOn::Identity::qt_create_metaobjectdata<qt_meta_tag_ZN6SignOn8IdentityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SignOn::Identity",
        "error",
        "",
        "SignOn::Error",
        "err",
        "methodsAvailable",
        "methods",
        "credentialsStored",
        "id",
        "referenceAdded",
        "referenceRemoved",
        "info",
        "SignOn::IdentityInfo",
        "userVerified",
        "valid",
        "secretVerified",
        "signedOut",
        "removed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(const SignOn::Error &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'methodsAvailable'
        QtMocHelpers::SignalData<void(const QStringList &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 6 },
        }}),
        // Signal 'credentialsStored'
        QtMocHelpers::SignalData<void(const quint32)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 8 },
        }}),
        // Signal 'referenceAdded'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'referenceRemoved'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'info'
        QtMocHelpers::SignalData<void(const SignOn::IdentityInfo &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 11 },
        }}),
        // Signal 'userVerified'
        QtMocHelpers::SignalData<void(const bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'secretVerified'
        QtMocHelpers::SignalData<void(const bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Signal 'signedOut'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Identity, qt_meta_tag_ZN6SignOn8IdentityE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SignOn::Identity::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn8IdentityE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn8IdentityE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SignOn8IdentityE_t>.metaTypes,
    nullptr
} };

void SignOn::Identity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Identity *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<SignOn::Error>>(_a[1]))); break;
        case 1: _t->methodsAvailable((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->credentialsStored((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 3: _t->referenceAdded(); break;
        case 4: _t->referenceRemoved(); break;
        case 5: _t->info((*reinterpret_cast<std::add_pointer_t<SignOn::IdentityInfo>>(_a[1]))); break;
        case 6: _t->userVerified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->secretVerified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->signedOut(); break;
        case 9: _t->removed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::Error >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::IdentityInfo >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Identity::*)(const SignOn::Error & )>(_a, &Identity::error, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)(const QStringList & )>(_a, &Identity::methodsAvailable, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)(const quint32 )>(_a, &Identity::credentialsStored, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)()>(_a, &Identity::referenceAdded, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)()>(_a, &Identity::referenceRemoved, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)(const SignOn::IdentityInfo & )>(_a, &Identity::info, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)(const bool )>(_a, &Identity::userVerified, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)(const bool )>(_a, &Identity::secretVerified, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)()>(_a, &Identity::signedOut, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Identity::*)()>(_a, &Identity::removed, 9))
            return;
    }
}

const QMetaObject *SignOn::Identity::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SignOn::Identity::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SignOn8IdentityE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SignOn::Identity::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void SignOn::Identity::error(const SignOn::Error & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SignOn::Identity::methodsAvailable(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SignOn::Identity::credentialsStored(const quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SignOn::Identity::referenceAdded()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void SignOn::Identity::referenceRemoved()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void SignOn::Identity::info(const SignOn::IdentityInfo & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void SignOn::Identity::userVerified(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void SignOn::Identity::secretVerified(const bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void SignOn::Identity::signedOut()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void SignOn::Identity::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
