/****************************************************************************
** Meta object code from reading C++ file 'authpluginif.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "SignOn/authpluginif.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'authpluginif.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AuthPluginInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto AuthPluginInterface::qt_create_metaobjectdata<qt_meta_tag_ZN19AuthPluginInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AuthPluginInterface",
        "result",
        "",
        "SignOn::SessionData",
        "data",
        "store",
        "error",
        "SignOn::Error",
        "err",
        "userActionRequired",
        "SignOn::UiSessionData",
        "refreshed",
        "statusChanged",
        "AuthPluginState",
        "state",
        "message",
        "userActionFinished",
        "refresh"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'result'
        QtMocHelpers::SignalData<void(const SignOn::SessionData &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'store'
        QtMocHelpers::SignalData<void(const SignOn::SessionData &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'error'
        QtMocHelpers::SignalData<void(const SignOn::Error &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'userActionRequired'
        QtMocHelpers::SignalData<void(const SignOn::UiSessionData &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Signal 'refreshed'
        QtMocHelpers::SignalData<void(const SignOn::UiSessionData &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(const AuthPluginState, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void(const AuthPluginState)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'userActionFinished'
        QtMocHelpers::SlotData<void(const SignOn::UiSessionData &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(const SignOn::UiSessionData &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AuthPluginInterface, qt_meta_tag_ZN19AuthPluginInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AuthPluginInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AuthPluginInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AuthPluginInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AuthPluginInterfaceE_t>.metaTypes,
    nullptr
} };

void AuthPluginInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AuthPluginInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->result((*reinterpret_cast<std::add_pointer_t<SignOn::SessionData>>(_a[1]))); break;
        case 1: _t->store((*reinterpret_cast<std::add_pointer_t<SignOn::SessionData>>(_a[1]))); break;
        case 2: _t->error((*reinterpret_cast<std::add_pointer_t<SignOn::Error>>(_a[1]))); break;
        case 3: _t->userActionRequired((*reinterpret_cast<std::add_pointer_t<SignOn::UiSessionData>>(_a[1]))); break;
        case 4: _t->refreshed((*reinterpret_cast<std::add_pointer_t<SignOn::UiSessionData>>(_a[1]))); break;
        case 5: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<AuthPluginState>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->statusChanged((*reinterpret_cast<std::add_pointer_t<AuthPluginState>>(_a[1]))); break;
        case 7: _t->userActionFinished((*reinterpret_cast<std::add_pointer_t<SignOn::UiSessionData>>(_a[1]))); break;
        case 8: _t->refresh((*reinterpret_cast<std::add_pointer_t<SignOn::UiSessionData>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::SessionData >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::SessionData >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::Error >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::UiSessionData >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::UiSessionData >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::UiSessionData >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< SignOn::UiSessionData >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AuthPluginInterface::*)(const SignOn::SessionData & )>(_a, &AuthPluginInterface::result, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthPluginInterface::*)(const SignOn::SessionData & )>(_a, &AuthPluginInterface::store, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthPluginInterface::*)(const SignOn::Error & )>(_a, &AuthPluginInterface::error, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthPluginInterface::*)(const SignOn::UiSessionData & )>(_a, &AuthPluginInterface::userActionRequired, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthPluginInterface::*)(const SignOn::UiSessionData & )>(_a, &AuthPluginInterface::refreshed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AuthPluginInterface::*)(const AuthPluginState , const QString & )>(_a, &AuthPluginInterface::statusChanged, 5))
            return;
    }
}

const QMetaObject *AuthPluginInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AuthPluginInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AuthPluginInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AuthPluginInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void AuthPluginInterface::result(const SignOn::SessionData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AuthPluginInterface::store(const SignOn::SessionData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AuthPluginInterface::error(const SignOn::Error & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AuthPluginInterface::userActionRequired(const SignOn::UiSessionData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AuthPluginInterface::refreshed(const SignOn::UiSessionData & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AuthPluginInterface::statusChanged(const AuthPluginState _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}
QT_WARNING_POP
