/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was com.nokia.SingleSignOn.Backup.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef BACKUP_ADAPTOR_H
#define BACKUP_ADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface com.nokia.backupclient
 */
class BackupclientAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "com.nokia.backupclient")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"com.nokia.backupclient\">\n"
"    <method name=\"backupStarts\">\n"
"      <arg direction=\"out\" type=\"y\"/>\n"
"    </method>\n"
"    <method name=\"backupFinished\">\n"
"      <arg direction=\"out\" type=\"y\"/>\n"
"    </method>\n"
"    <method name=\"restoreStarts\">\n"
"      <arg direction=\"out\" type=\"y\"/>\n"
"    </method>\n"
"    <method name=\"restoreFinished\">\n"
"      <arg direction=\"out\" type=\"y\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    BackupclientAdaptor(QObject *parent);
    ~BackupclientAdaptor() override;

public: // PROPERTIES
public Q_SLOTS: // METHODS
    uchar backupFinished();
    uchar backupStarts();
    uchar restoreFinished();
    uchar restoreStarts();
Q_SIGNALS: // SIGNALS
};

#endif
